/* Include this before everything else, for various large-file definitions */
#include "config.h"
#include <wireshark.h>

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

/* %not-for-header */
/* %if-c-only */
/* %if-not-reentrant */
/* %endif */
/* %endif */
/* %ok-for-header */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* %if-c++-only */
/* %endif */

/* %if-c-only */
#ifdef yy_create_buffer
#define ascend__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer ascend__create_buffer
#endif

#ifdef yy_delete_buffer
#define ascend__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer ascend__delete_buffer
#endif

#ifdef yy_scan_buffer
#define ascend__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer ascend__scan_buffer
#endif

#ifdef yy_scan_string
#define ascend__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string ascend__scan_string
#endif

#ifdef yy_scan_bytes
#define ascend__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes ascend__scan_bytes
#endif

#ifdef yy_init_buffer
#define ascend__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer ascend__init_buffer
#endif

#ifdef yy_flush_buffer
#define ascend__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer ascend__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define ascend__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state ascend__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define ascend__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer ascend__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define ascend_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state ascend_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define ascend_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state ascend_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define ascend_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack ascend_ensure_buffer_stack
#endif

#ifdef yylex
#define ascend_lex_ALREADY_DEFINED
#else
#define yylex ascend_lex
#endif

#ifdef yyrestart
#define ascend_restart_ALREADY_DEFINED
#else
#define yyrestart ascend_restart
#endif

#ifdef yylex_init
#define ascend_lex_init_ALREADY_DEFINED
#else
#define yylex_init ascend_lex_init
#endif

#ifdef yylex_init_extra
#define ascend_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra ascend_lex_init_extra
#endif

#ifdef yylex_destroy
#define ascend_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy ascend_lex_destroy
#endif

#ifdef yyget_debug
#define ascend_get_debug_ALREADY_DEFINED
#else
#define yyget_debug ascend_get_debug
#endif

#ifdef yyset_debug
#define ascend_set_debug_ALREADY_DEFINED
#else
#define yyset_debug ascend_set_debug
#endif

#ifdef yyget_extra
#define ascend_get_extra_ALREADY_DEFINED
#else
#define yyget_extra ascend_get_extra
#endif

#ifdef yyset_extra
#define ascend_set_extra_ALREADY_DEFINED
#else
#define yyset_extra ascend_set_extra
#endif

#ifdef yyget_in
#define ascend_get_in_ALREADY_DEFINED
#else
#define yyget_in ascend_get_in
#endif

#ifdef yyset_in
#define ascend_set_in_ALREADY_DEFINED
#else
#define yyset_in ascend_set_in
#endif

#ifdef yyget_out
#define ascend_get_out_ALREADY_DEFINED
#else
#define yyget_out ascend_get_out
#endif

#ifdef yyset_out
#define ascend_set_out_ALREADY_DEFINED
#else
#define yyset_out ascend_set_out
#endif

#ifdef yyget_leng
#define ascend_get_leng_ALREADY_DEFINED
#else
#define yyget_leng ascend_get_leng
#endif

#ifdef yyget_text
#define ascend_get_text_ALREADY_DEFINED
#else
#define yyget_text ascend_get_text
#endif

#ifdef yyget_lineno
#define ascend_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno ascend_get_lineno
#endif

#ifdef yyset_lineno
#define ascend_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno ascend_set_lineno
#endif

#ifdef yyget_column
#define ascend_get_column_ALREADY_DEFINED
#else
#define yyget_column ascend_get_column
#endif

#ifdef yyset_column
#define ascend_set_column_ALREADY_DEFINED
#else
#define yyset_column ascend_set_column
#endif

#ifdef yywrap
#define ascend_wrap_ALREADY_DEFINED
#else
#define yywrap ascend_wrap
#endif

/* %endif */

#ifdef yyalloc
#define ascend_alloc_ALREADY_DEFINED
#else
#define yyalloc ascend_alloc
#endif

#ifdef yyrealloc
#define ascend_realloc_ALREADY_DEFINED
#else
#define yyrealloc ascend_realloc
#endif

#ifdef yyfree
#define ascend_free_ALREADY_DEFINED
#else
#define yyfree ascend_free
#endif

/* %if-c-only */

/* %endif */

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
/* %if-c-only */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>
/* %endif */

/* %if-tables-serialization */
/* %endif */
/* end standard C headers. */

/* %if-c-or-c++ */
/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* %endif */

/* begin standard C++ headers. */
/* %if-c++-only */
/* %endif */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* %not-for-header */
/* Returned upon end-of-file. */
#define YY_NULL 0
/* %ok-for-header */

/* %not-for-header */
/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))
/* %ok-for-header */

/* %if-reentrant */

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* %endif */

/* %if-not-reentrant */
/* %endif */

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

/* %if-not-reentrant */
/* %endif */

/* %if-c-only */
/* %if-not-reentrant */
/* %endif */
/* %endif */

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
/* %if-c-only */
	FILE *yy_input_file;
/* %endif */

/* %if-c++-only */
/* %endif */

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */
/* %if-not-reentrant */
/* %endif */
/* %ok-for-header */

/* %endif */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

/* %if-c-only Standard (non-C++) definition */

/* %if-not-reentrant */
/* %not-for-header */
/* %ok-for-header */

/* %endif */

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

/* %endif */

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* %% [1.0] yytext/yyin/yyout/yy_state_type/yylineno etc. def's & init go here */
/* Begin user sect3 */

#define ascend_wrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

#define FLEX_DEBUG
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

/* %% [1.5] DFA */

/* %if-c-only Standard (non-C++) definition */

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* %endif */

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
/* %% [2.0] code to fiddle yytext and yyleng for yymore() goes here \ */\
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
/* %% [3.0] code to copy yytext_ptr to yytext[] goes here, if %array \ */\
	yyg->yy_c_buf_p = yy_cp;
/* %% [4.0] data tables for the DFA and the user's section 1 definitions go here */
#define YY_NUM_RULES 38
#define YY_END_OF_BUFFER 39
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[489] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   11,   11,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   20,   20,    0,    0,    0,    0,   39,   37,
       35,   35,   35,   35,   37,   37,   37,   37,   35,   37,
       37,   37,   37,   35,   35,   35,   14,   14,   15,   15,
       16,   16,   37,   37,   35,   35,   35,   35,   35,   37,
       35,   35,   35,   37,   37,   11,   11,   37,   35,   35,
       35,   35,   37,   35,   35,   37,   35,   35,   35,   30,

       30,   30,   30,   30,   30,   32,   32,   32,   37,   20,
       20,   20,   20,   20,   20,    9,    9,    9,    9,    9,
        9,   37,   35,   35,   35,   37,   37,   35,    0,   35,
        0,    0,    0,    0,    0,    0,   36,    0,    0,    0,
        0,   34,   12,    0,   14,   15,   16,    0,    0,   18,
       18,   10,   10,   10,   10,   10,   10,   10,   11,    0,
       22,   35,    0,   26,    0,   28,   35,   30,   30,   30,
       30,   30,   30,   30,   32,    0,   20,   20,   20,   20,
       20,   20,   20,    9,    9,    9,    9,    9,    9,    9,
        8,    8,    8,    8,    8,    8,    8,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,   13,   12,   35,
       14,   15,   16,    0,    0,   10,   10,   10,   10,   10,
        0,   35,    0,    0,    0,   30,   30,   30,   32,    0,
       20,   20,   20,    9,    9,    9,    9,    9,    8,    8,
        8,    8,    8,    0,    0,    0,    0,    5,    0,    4,
        0,   36,    0,   12,   14,   15,   16,    0,   19,   10,
       10,   10,   10,   10,   23,   24,    0,   27,    0,   30,
       30,   30,   32,    0,   20,   20,   20,    9,    9,    9,
        9,    9,    8,    8,    8,    8,    8,   21,    1,    0,
        0,    0,    0,    5,    0,    4,    0,   12,   14,   15,

       16,    0,   10,   10,   10,   25,    0,   30,   32,    0,
       20,    9,    9,    9,    8,    8,    8,    8,    7,    0,
        0,    0,    0,   12,   14,   15,   16,    0,   10,   10,
       10,    0,   32,   33,    9,    9,    9,    8,    8,    8,
        6,    0,    0,    0,   12,   14,   16,   17,   10,   10,
        0,   32,    9,    9,    8,    8,    3,    0,    0,   12,
       14,   16,   10,   10,    0,   32,    9,    9,    8,    8,
        2,    0,   14,   16,   10,   10,    0,    9,    9,    8,
        8,    0,   14,   16,   10,   10,    0,    9,    9,    8,
        8,    0,   10,   10,    0,    9,    9,    8,    8,    0,

       10,   10,    0,    9,    9,    8,    8,    0,   10,   10,
        0,    9,    9,    8,    8,    0,   10,   10,    0,    9,
        9,    8,    8,    0,   10,   10,    0,    9,    9,    8,
        8,    0,   10,   10,    0,    9,    9,    8,    8,    0,
       10,   10,    0,    9,    9,    8,    8,    0,   10,   10,
        0,    9,    9,    8,    8,    0,   10,   10,    0,    9,
        9,    8,    8,    0,   10,   10,    0,    9,    9,    8,
        8,    0,    0,   31,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   29,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    1,    5,    1,    1,    1,    1,    1,    6,
        1,    1,    1,    1,    7,    1,    8,    9,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   11,    1,    1,
        1,    1,    1,    1,   12,   13,   14,   15,   16,   13,
       17,   18,   19,   17,   17,   20,   21,   22,   23,   24,
       17,   25,   26,   27,   28,   29,   30,   31,   17,   17,
       32,    1,   33,    1,   34,    1,   35,   13,   36,   13,

       37,   13,   17,   38,   39,   17,   40,   41,   42,   43,
       44,   45,   17,   17,   46,   47,   48,   17,   17,   49,
       50,   17,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[51] =
    {   0,
        1,    2,    3,    4,    1,    5,    1,    6,    7,    7,
        8,    7,    7,    7,    7,    7,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
       10,    1,    1,    9,    7,    7,    7,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,   10,    9
    } ;

static const flex_int16_t yy_base[579] =
    {   0,
        0,   39,   82,    0,  121,  144,  167,  190,  213,  236,
        2,   41,  264,    0,  293,  332,  371,  394,   85,   97,
      417,  440,  463,  486,  108,  140,  509,  532,  178,  201,
      555,  578,  225,  267,  608,  654,  238,  295,  697,    0,
      308,  335,  732,  777,  819,  861,  903,  945,  699, 3447,
        9,   10,  662,  669,    4,  679,  679,  672,  645,  652,
        3,    0,   10,   12,   19,  640,   36,   12,   68,   70,
       72,   79,    0,  682,   53,   76,  650,  657,  636,    0,
      984,  109,  131,  646,   64,  132,  134,  138,  140,  163,
      175,  177,  642,  186,  201,  209,  224,  226,  645,    0,

     1025,  130,  239,  643,   69,  132,  193,  631,  277,    0,
     1066,  199,  240,  641,  255,    0, 1107,  216,  287,  640,
      278,    0, 1148,  226,  323,  639,  286,    0,    0,  627,
      655,  648,  652,  651,  628,  642, 3447,  613,  613,  612,
      648,  249,    0,    0,  275,  305,  343,    0,  647,    0,
      603,    0, 1189,    0,    0,  602,  602,  605,    0,  347,
        0,  352,  604,    0,  354,    0,  594,    0,  300,  340,
        0,  594,  594,  597,    0,  593,    0,  342,  343,    0,
      590,  590,  593,    0, 1218,    0,    0,  587,  587,  590,
        0, 1247,    0,    0,  584,  584,  587,  591,  611,  619,

      618,  590,  601,  588,  577,  573,  570, 3447,    0,    0,
      368,  374,  384,    0,  602,    0, 1276,  568,  564,  564,
      592,  388,  562,  587,  551,  559,  555,  555,    0,  554,
      553,  549,  547,    0, 1305,  546,  542,  544,    0, 1334,
      541,  537,  539,  564,  549,  388,   89,    0,  554,  401,
      525,  558,  557,    0,  390,  396,  404,    0, 3447,    0,
     1363,  520,  555,  550, 3447,    0,  549, 3447,  522,  511,
      544,  543,    0,  549,  505,  540,  539,    0, 1392,  502,
      535,  534,    0, 1421,  497,  532,  527, 3447, 3447,  515,
      508,  521,  511,  409,  519,  410,  484,    0,  413,  419,

      421,  496,    0, 1450,  482, 3447,  523,  480,    0,    0,
      477,    0, 1479,  476,    0, 1508,  475,    0, 3447,  493,
      486,  495,  493,    0,  425,    0,  427,  501,    0, 1537,
        0,  474,    0,    0,    0, 1566,    0,    0, 1595,    0,
     3447,  501,  480,  483,    0,  429,  434, 3447,    0, 1624,
      462,    0,    0, 1653,    0, 1682, 3447,  497,  475,    0,
      436,  442,    0, 1711,  496,    0,    0, 1740,    0, 1769,
     3447,  472,  444,  448,    0, 1798,  463,    0, 1827,    0,
     1856,  463,    0,    0,    0, 1885,  445,    0, 1914,    0,
     1943,  476,    0, 1972,  443,    0, 2001,    0, 2030,  470,

        0, 2059,  449,    0, 2088,    0, 2117,  459,    0, 2146,
      442,    0, 2175,    0, 2204,  459,    0, 2233,  437,    0,
     2262,    0, 2291,  470,    0, 2320,  433,    0, 2349,    0,
     2378,  473,    0, 2407,  472,    0, 2436,    0, 2465,  439,
        0, 2494,  427,    0, 2523,    0, 2552,  431,    0, 2581,
      424,    0, 2610,    0, 2639,  419,    0, 2668,  462,    0,
     2697,    0, 2726,  420, 3447,    0,  417, 3447,    0, 3447,
        0,  421,  419, 3447,  424,  404,  378,  386,  352,  350,
      334,  317,  331,  275,  251,  289, 3447, 3447, 2763, 2773,
     2783, 2793, 2803, 2813, 2817, 2824, 2828,  265, 2832, 2842,

     2852, 2856, 2866, 2876, 2886,  257,  220,  206, 2896,  200,
     2906, 2916,  197,  194,  183, 2926,  181, 2936, 2946,  159,
      150, 2956,  127, 2966, 2976,  104, 2986,   99, 2996, 3006,
     3016,   55, 3026,   53, 3036, 3046,   32, 3056,   16, 3066,
     3076, 3086, 3096, 3106, 3116, 3126, 3136, 3146, 3156, 3166,
     3176, 3186, 3196, 3206, 3216, 3226, 3236, 3246, 3256, 3266,
     3276, 3286, 3296, 3306, 3316, 3326, 3336, 3346, 3356, 3366,
     3376, 3386, 3396, 3406, 3416, 3426, 3436,    1
    } ;

static const flex_int16_t yy_def[579] =
    {   0,
      489,  489,  489,    3,    2,    2,    2,    2,    2,    2,
        2,    2,    2,   13,  490,  490,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,  491,  491,    2,    2,    3,   39,
        2,    2,  492,  492,  493,  493,  494,  494,  488,  488,
      495,  495,   52,   52,  488,  488,  488,  488,   52,  488,
      488,  496,  488,  497,  497,   65,   52,   52,   67,   52,
       67,   52,  498,  488,  499,  499,   76,   76,   76,  500,
      500,   81,   81,  500,  500,   67,   52,  488,   67,   52,
       67,   52,  488,   67,   52,  488,   67,   52,   52,  501,

      501,  101,  101,  501,  501,  502,  502,  107,  488,  503,
      503,  111,  111,  503,  503,  504,  504,  117,  117,  504,
      504,  505,  505,  123,  123,  505,  505,   52,   52,   52,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      496,  488,  506,  507,   52,   52,   52,  508,  488,   52,
       52,  509,  509,  153,  509,  509,  509,  509,   87,  488,
       52,   52,  488,   52,  488,   52,   52,  501,  101,  101,
      501,  501,  501,  501,  510,  488,  503,  111,  111,  503,
      503,  503,  503,  511,  511,  185,  511,  511,  511,  511,
      512,  512,  192,  512,  512,  512,  512,  488,  488,  488,

      488,  488,  488,  488,  488,  488,  488,  488,  513,  514,
       52,   52,   52,  515,  488,  516,  516,  516,  516,  516,
      488,   52,  488,  488,  488,  501,  501,  501,  517,  488,
      503,  503,  503,  518,  518,  518,  518,  518,  519,  519,
      519,  519,  519,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  520,   52,   52,   52,  521,  488,  522,
      522,  522,  522,  522,  488,   52,  488,  488,  488,  501,
      501,  501,  523,  488,  503,  503,  503,  524,  524,  524,
      524,  524,  525,  525,  525,  525,  525,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  526,   52,   52,

       52,  488,  527,  527,  527,  488,  488,  501,  528,  529,
      503,  530,  530,  530,  531,  531,  531,  531,  488,  488,
      488,  488,  488,  532,   52,   52,   52,  488,  533,  533,
      533,  488,  534,  529,  535,  535,  535,  536,  536,  536,
      488,  488,  488,  488,  537,   52,   52,  488,  538,  538,
      488,  539,  540,  540,  541,  541,  488,  488,  488,   52,
       52,   52,  542,  542,  488,   52,  543,  543,  544,  544,
      488,  488,   52,   52,  545,  545,  488,  546,  546,  547,
      547,  488,   52,   52,  548,  548,  488,  549,  549,  550,
      550,  488,  551,  551,  488,  552,  552,  553,  553,  488,

      554,  554,  488,  555,  555,  556,  556,  488,  557,  557,
      488,  558,  558,  559,  559,  488,  560,  560,  488,  561,
      561,  562,  562,  488,  563,  563,  488,  564,  564,  565,
      565,  488,  566,  566,  488,  567,  567,  568,  568,  488,
      569,  569,  488,  570,  570,  571,  571,  488,  572,  572,
      488,  573,  573,  574,  574,  488,  575,  575,  488,  576,
      576,  577,  577,  488,  488,  578,  488,  488,  578,  488,
      578,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,    0,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,

      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488
    } ;

static const flex_int16_t yy_nxt[3498] =
    {   0,
      488,  488,  488,  488,  488,  488,  294,  128,   51,   52,
      294,   52,   52,   52,   53,   54,   52,   52,  142,  142,
      145,  145,  366,   55,   56,   50,   50,  132,  133,   57,
       58,   50,   50,   73,   59,   52,   52,  139,  360,  129,
      488,  140,  144,   60,  145,  145,   61,   51,   52,  488,
       52,   52,   52,   53,   54,   52,   52,  129,  488,  352,
      144,  345,   55,   56,   50,   50,  129,  488,   57,   58,
       50,   50,   73,   59,   52,   52,  146,  146,  146,  146,
      147,  147,   60,  129,  129,   61,   62,  147,  147,   63,
       64,   65,   88,   65,   65,   65,   65,   65,  157,   52,

       52,  129,  158,  173,   88,  333,  488,  174,   50,   50,
      324,   52,   52,  292,   50,   50,   66,   65,   65,  293,
       50,   50,   52,   52,  488,   60,   50,   50,   61,   67,
       68,   50,   50,  309,   93,   52,   52,   50,   50,  152,
      159,  159,  159,  159,   50,   50,  160,  160,  161,  161,
       50,   50,   67,   68,   52,   52,  302,  152,   52,   52,
      168,  152,  129,   50,   50,  298,   93,   50,   50,   50,
       50,  161,  161,   50,   50,   69,   70,  155,  168,  152,
      129,   52,   52,  162,  162,  162,  162,  273,   96,  258,
       50,   50,   52,   52,  164,  164,   50,   50,   69,   70,

      143,   50,   50,  254,   52,   52,  229,   50,   50,  164,
      164,   96,  214,   50,   50,   52,   52,  165,  165,   50,
       50,   71,   72,  488,   50,   50,  210,   52,   52,  177,
       50,   50,  166,  166,  166,  166,   50,   50,   99,   52,
       52,  488,   50,   50,   71,   72,  184,  177,   50,   50,
       52,   52,   52,   52,   50,   50,  191,  142,  142,   50,
       50,   50,   50,  209,  184,   50,   50,   74,   50,  168,
      177,  148,   75,   76,  191,   76,   76,   76,   77,   78,
       99,   52,   52,  211,  211,  171,  180,  168,  177,  182,
       50,   50,  487,  183,  486,   73,   50,   50,   79,   76,

       76,   81,   82,   50,   82,   82,   82,   82,   82,   52,
       52,  139,  189,  212,  212,  140,  190,  184,   50,   50,
      196,  485,   52,   52,  197,   50,  176,   83,   82,   82,
      168,   50,   50,  187,  484,  184,   84,   50,   50,   85,
       81,   82,   50,   82,   82,   82,   82,   82,  168,   52,
       52,  213,  213,  191,  109,  221,  221,  483,   50,   50,
      222,  222,  224,  224,   50,   50,   83,   82,   82,  194,
      168,  191,  177,  177,  482,   84,  255,  255,   85,   86,
       87,  109,  256,  256,  481,   52,   52,  480,  168,  479,
      177,  177,  257,  257,   50,   50,  266,  266,  299,  299,

       50,   50,   86,   87,  300,  300,  290,  296,   52,   52,
      291,  296,  301,  301,  478,  294,  296,   50,   50,  294,
      296,  325,  325,   50,   50,   89,   90,  326,  326,  327,
      327,   52,   52,  346,  346,  347,  347,  361,  361,  477,
       50,   50,  362,  362,  373,  373,   50,   50,   89,   90,
      374,  374,  383,  383,   52,   52,  384,  384,  476,  475,
      474,  473,  472,   50,   50,  467,  464,  459,  456,   50,
       50,   91,   92,  451,  448,  443,  440,   52,   52,  435,
      432,  427,  424,  419,  416,  411,   50,   50,  408,  403,
      400,  395,   50,   50,   91,   92,  392,  387,  382,  377,

       52,   52,  372,  371,  365,  359,  358,  357,  351,   50,
       50,  348,  344,  343,  342,   50,   50,   94,   95,  341,
      340,  337,  180,   52,   52,  171,  332,  331,  328,  137,
      323,  322,   50,   50,  321,  320,  319,  318,   50,   50,
       94,   95,  318,  317,  137,  137,   52,   52,  314,  180,
      180,  311,  310,  171,  171,   50,   50,  308,  307,  306,
      137,   50,   50,   97,   98,  137,  305,  137,  137,   52,
       52,  297,  295,  289,  288,  287,  286,  285,   50,   50,
      282,  281,  280,  277,   50,   50,   97,   98,  276,  275,
      274,  272,   52,   52,  271,  270,  269,  268,  267,  265,

      264,   50,   50,  263,  262,  259,  253,   50,   50,   50,
       50,   50,  252,  251,  250,  249,  101,  102,  248,  102,
      102,  102,  102,  102,  247,  246,  245,  244,  243,  242,
      241,  238,  237,  236,  233,  232,  231,  230,  228,  227,
      226,  225,  103,  102,  102,  223,  220,  219,  218,  198,
      215,  104,  208,  207,  105,   50,   50,   50,  206,  205,
      204,  203,  101,  102,  202,  102,  102,  102,  102,  102,
      201,  200,  199,  198,  195,  188,  181,  137,  172,  167,
      163,  156,  137,  131,  151,  149,  137,  138,  103,  102,
      102,  137,  136,  135,  134,  131,  130,  104,  488,  488,

      105,   50,  488,  488,   50,  106,  107,  488,  107,  107,
      107,  107,  107,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  108,  107,  107,   50,  488,  488,  488,  488,  488,
      111,  112,  488,  112,  112,  112,  112,  112,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  113,  112,  112,  488,
      488,  488,  488,  488,  488,  114,  488,  488,  115,   50,
      488,  488,  488,  488,  488,  111,  112,  488,  112,  112,
      112,  112,  112,  488,  488,  488,  488,  488,  488,  488,

      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  113,  112,  112,  488,  488,  488,  488,  488,  488,
      114,  488,  488,  115,   50,  488,   50,  117,  118,   50,
      118,  118,  118,  118,  118,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  119,  118,  118,  488,  488,  488,  488,
      488,  488,  120,  488,  488,  121,   50,  488,   50,  117,
      118,   50,  118,  118,  118,  118,  118,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  119,  118,  118,  488,  488,

      488,  488,  488,  488,  120,  488,  488,  121,   50,  488,
      488,  123,  124,  488,  124,  124,  124,  124,  124,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  125,  124,  124,
      488,  488,  488,  488,  488,  488,  126,  488,  488,  127,
       50,  488,  488,  123,  124,  488,  124,  124,  124,  124,
      124,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  125,
      124,  124,  488,  488,  488,  488,  488,  488,  126,  488,
      488,  127,  153,  153,  488,  153,  153,  153,  153,  153,

      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  154,  488,  488,  488,  153,  153,
      153,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  154,  169,  169,  488,  169,  169,  169,  169,
      169,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  170,  488,  488,  488,  169,
      169,  169,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  170,  178,  178,  488,  178,  178,  178,
      178,  178,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  179,  488,  488,  488,

      178,  178,  178,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  179,  185,  185,  488,  185,  185,
      185,  185,  185,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  186,  488,  488,
      488,  185,  185,  185,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  186,  192,  192,  488,  192,
      192,  192,  192,  192,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  193,  488,
      488,  488,  192,  192,  192,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  193,  217,  217,  488,

      217,  217,  217,  217,  217,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  217,  217,  217,  235,  235,  488,  235,
      235,  235,  235,  235,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  235,  235,  235,  240,  240,  488,  240,  240,
      240,  240,  240,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  240,  240,  240,  261,  261,  488,  261,  261,  261,
      261,  261,  488,  488,  488,  488,  488,  488,  488,  488,

      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      261,  261,  261,  279,  279,  488,  279,  279,  279,  279,
      279,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  279,
      279,  279,  284,  284,  488,  284,  284,  284,  284,  284,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  284,  284,
      284,  304,  304,  488,  304,  304,  304,  304,  304,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  304,  304,  304,

      313,  313,  488,  313,  313,  313,  313,  313,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  313,  313,  313,  316,
      316,  488,  316,  316,  316,  316,  316,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  316,  316,  316,  330,  330,
      488,  330,  330,  330,  330,  330,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  330,  330,  330,  336,  336,  488,
      336,  336,  336,  336,  336,  488,  488,  488,  488,  488,

      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  336,  336,  336,  339,  339,  488,  339,
      339,  339,  339,  339,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  339,  339,  339,  350,  350,  488,  350,  350,
      350,  350,  350,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  350,  350,  350,  354,  354,  488,  354,  354,  354,
      354,  354,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,

      354,  354,  354,  356,  356,  488,  356,  356,  356,  356,
      356,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  356,
      356,  356,  364,  364,  488,  364,  364,  364,  364,  364,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  364,  364,
      364,  368,  368,  488,  368,  368,  368,  368,  368,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  368,  368,  368,
      370,  370,  488,  370,  370,  370,  370,  370,  488,  488,

      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  370,  370,  370,  376,
      376,  488,  376,  376,  376,  376,  376,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  376,  376,  376,  379,  379,
      488,  379,  379,  379,  379,  379,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  379,  379,  379,  381,  381,  488,
      381,  381,  381,  381,  381,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,

      488,  488,  488,  381,  381,  381,  386,  386,  488,  386,
      386,  386,  386,  386,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  386,  386,  386,  389,  389,  488,  389,  389,
      389,  389,  389,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  389,  389,  389,  391,  391,  488,  391,  391,  391,
      391,  391,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      391,  391,  391,  394,  394,  488,  394,  394,  394,  394,

      394,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  394,
      394,  394,  397,  397,  488,  397,  397,  397,  397,  397,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  397,  397,
      397,  399,  399,  488,  399,  399,  399,  399,  399,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  399,  399,  399,
      402,  402,  488,  402,  402,  402,  402,  402,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,

      488,  488,  488,  488,  488,  488,  402,  402,  402,  405,
      405,  488,  405,  405,  405,  405,  405,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  405,  405,  405,  407,  407,
      488,  407,  407,  407,  407,  407,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  407,  407,  407,  410,  410,  488,
      410,  410,  410,  410,  410,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  410,  410,  410,  413,  413,  488,  413,

      413,  413,  413,  413,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  413,  413,  413,  415,  415,  488,  415,  415,
      415,  415,  415,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  415,  415,  415,  418,  418,  488,  418,  418,  418,
      418,  418,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      418,  418,  418,  421,  421,  488,  421,  421,  421,  421,
      421,  488,  488,  488,  488,  488,  488,  488,  488,  488,

      488,  488,  488,  488,  488,  488,  488,  488,  488,  421,
      421,  421,  423,  423,  488,  423,  423,  423,  423,  423,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  423,  423,
      423,  426,  426,  488,  426,  426,  426,  426,  426,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  426,  426,  426,
      429,  429,  488,  429,  429,  429,  429,  429,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  429,  429,  429,  431,

      431,  488,  431,  431,  431,  431,  431,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  431,  431,  431,  434,  434,
      488,  434,  434,  434,  434,  434,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  434,  434,  434,  437,  437,  488,
      437,  437,  437,  437,  437,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  437,  437,  437,  439,  439,  488,  439,
      439,  439,  439,  439,  488,  488,  488,  488,  488,  488,

      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  439,  439,  439,  442,  442,  488,  442,  442,
      442,  442,  442,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  442,  442,  442,  445,  445,  488,  445,  445,  445,
      445,  445,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      445,  445,  445,  447,  447,  488,  447,  447,  447,  447,
      447,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  447,

      447,  447,  450,  450,  488,  450,  450,  450,  450,  450,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  450,  450,
      450,  453,  453,  488,  453,  453,  453,  453,  453,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  453,  453,  453,
      455,  455,  488,  455,  455,  455,  455,  455,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  455,  455,  455,  458,
      458,  488,  458,  458,  458,  458,  458,  488,  488,  488,

      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  458,  458,  458,  461,  461,
      488,  461,  461,  461,  461,  461,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  461,  461,  461,  463,  463,  488,
      463,  463,  463,  463,  463,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  463,  463,  463,  466,  466,  488,  466,
      466,  466,  466,  466,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,

      488,  488,  466,  466,  466,  469,  469,  488,  469,  469,
      469,  469,  469,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  469,  469,  469,  471,  471,  488,  471,  471,  471,
      471,  471,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      471,  471,  471,   50,   50,   50,   50,   50,   50,   50,
       50,   50,   50,   80,   80,   80,   80,   80,   80,   80,
       80,   80,   80,  100,  100,  100,  100,  100,  100,  100,
      100,  100,  100,  110,  110,  110,  110,  110,  110,  110,

      110,  110,  110,  116,  116,  116,  116,  116,  116,  116,
      116,  116,  116,  122,  122,  122,  122,  122,  122,  122,
      122,  122,  122,  128,  488,  488,  128,  141,  488,  488,
      141,  488,  141,  141,  143,  488,  488,  143,  150,  488,
      488,  150,  152,  152,  152,  152,  152,  152,  152,  488,
      152,  152,  168,  488,  488,  488,  168,  168,  168,  168,
      168,  168,  175,  488,  488,  175,  177,  177,  488,  177,
      177,  177,  177,  177,  177,  177,  184,  184,  184,  184,
      488,  488,  184,  488,  184,  184,  191,  191,  191,  191,
      488,  191,  191,  191,  191,  191,  216,  216,  216,  216,

      216,  216,  216,  488,  216,  216,  234,  234,  234,  234,
      488,  488,  234,  488,  234,  234,  239,  239,  239,  239,
      488,  239,  239,  239,  239,  239,  260,  260,  260,  260,
      260,  260,  260,  488,  260,  260,  278,  278,  278,  278,
      488,  488,  278,  488,  278,  278,  283,  283,  283,  283,
      488,  283,  283,  283,  283,  283,  303,  303,  303,  303,
      303,  303,  303,  488,  303,  303,  312,  312,  312,  312,
      488,  488,  312,  488,  312,  312,  315,  315,  315,  315,
      488,  315,  315,  315,  315,  315,  329,  329,  329,  329,
      329,  329,  329,  488,  329,  329,  334,  488,  488,  488,

      334,  334,  334,  334,  334,  334,  335,  335,  335,  335,
      488,  488,  335,  488,  335,  335,  338,  338,  338,  338,
      488,  338,  338,  338,  338,  338,  349,  349,  349,  349,
      349,  349,  349,  488,  349,  349,  353,  353,  353,  353,
      488,  488,  353,  488,  353,  353,  355,  355,  355,  355,
      488,  355,  355,  355,  355,  355,  363,  363,  363,  363,
      363,  363,  363,  488,  363,  363,  367,  367,  367,  367,
      488,  488,  367,  488,  367,  367,  369,  369,  369,  369,
      488,  369,  369,  369,  369,  369,  375,  375,  375,  375,
      375,  375,  375,  488,  375,  375,  378,  378,  378,  378,

      488,  488,  378,  488,  378,  378,  380,  380,  380,  380,
      488,  380,  380,  380,  380,  380,  385,  385,  385,  385,
      385,  385,  385,  488,  385,  385,  388,  388,  388,  388,
      488,  488,  388,  488,  388,  388,  390,  390,  390,  390,
      488,  390,  390,  390,  390,  390,  393,  393,  393,  393,
      393,  393,  393,  488,  393,  393,  396,  396,  396,  396,
      488,  488,  396,  488,  396,  396,  398,  398,  398,  398,
      488,  398,  398,  398,  398,  398,  401,  401,  401,  401,
      401,  401,  401,  488,  401,  401,  404,  404,  404,  404,
      488,  488,  404,  488,  404,  404,  406,  406,  406,  406,

      488,  406,  406,  406,  406,  406,  409,  409,  409,  409,
      409,  409,  409,  488,  409,  409,  412,  412,  412,  412,
      488,  488,  412,  488,  412,  412,  414,  414,  414,  414,
      488,  414,  414,  414,  414,  414,  417,  417,  417,  417,
      417,  417,  417,  488,  417,  417,  420,  420,  420,  420,
      488,  488,  420,  488,  420,  420,  422,  422,  422,  422,
      488,  422,  422,  422,  422,  422,  425,  425,  425,  425,
      425,  425,  425,  488,  425,  425,  428,  428,  428,  428,
      488,  488,  428,  488,  428,  428,  430,  430,  430,  430,
      488,  430,  430,  430,  430,  430,  433,  433,  433,  433,

      433,  433,  433,  488,  433,  433,  436,  436,  436,  436,
      488,  488,  436,  488,  436,  436,  438,  438,  438,  438,
      488,  438,  438,  438,  438,  438,  441,  441,  441,  441,
      441,  441,  441,  488,  441,  441,  444,  444,  444,  444,
      488,  488,  444,  488,  444,  444,  446,  446,  446,  446,
      488,  446,  446,  446,  446,  446,  449,  449,  449,  449,
      449,  449,  449,  488,  449,  449,  452,  452,  452,  452,
      488,  488,  452,  488,  452,  452,  454,  454,  454,  454,
      488,  454,  454,  454,  454,  454,  457,  457,  457,  457,
      457,  457,  457,  488,  457,  457,  460,  460,  460,  460,

      488,  488,  460,  488,  460,  460,  462,  462,  462,  462,
      488,  462,  462,  462,  462,  462,  465,  465,  465,  465,
      465,  465,  465,  488,  465,  465,  468,  468,  468,  468,
      488,  488,  468,  488,  468,  468,  470,  470,  470,  470,
      488,  470,  470,  470,  470,  470,   49,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488

    } ;

static const flex_int16_t yy_chk[3498] =
    {   0,
        0,    0,    0,    0,    0,    0,  248,  578,    1,    1,
      248,    1,    1,    1,    1,    1,   11,   11,   63,   63,
       68,   68,  539,    1,    1,   11,   11,   55,   55,    1,
        1,   11,   11,   11,    1,    1,    1,   61,  537,   51,
       52,   61,   64,    1,   67,   67,    1,    2,    2,   65,
        2,    2,    2,    2,    2,   12,   12,   51,   52,  534,
       64,  532,    2,    2,   12,   12,   67,   65,    2,    2,
       12,   12,   12,    2,    2,    2,   69,   69,   70,   70,
       71,   71,    2,   75,   67,    2,    3,   72,   72,    3,
        3,    3,   19,    3,    3,    3,    3,    3,   85,   19,

       19,   75,   85,  105,   20,  528,   76,  105,   19,   19,
      526,   20,   20,  247,   19,   19,    3,    3,    3,  247,
       20,   20,   25,   25,   76,    3,   20,   20,    3,    5,
        5,   25,   25,  523,   25,    5,    5,   25,   25,   82,
       86,   86,   87,   87,    5,    5,   88,   88,   89,   89,
        5,    5,    6,    6,   26,   26,  521,   82,    6,    6,
      102,   83,  106,   26,   26,  520,   26,    6,    6,   26,
       26,   90,   90,    6,    6,    7,    7,   83,  102,   83,
      106,    7,    7,   91,   91,   92,   92,  517,   29,  515,
        7,    7,   29,   29,   94,   94,    7,    7,    8,    8,

      514,   29,   29,  513,    8,    8,  510,   29,   29,   95,
       95,   30,  508,    8,    8,   30,   30,   96,   96,    8,
        8,    9,    9,  107,   30,   30,  507,    9,    9,  112,
       30,   30,   97,   97,   98,   98,    9,    9,   33,   33,
       33,  107,    9,    9,   10,   10,  118,  112,   33,   33,
       10,   10,   37,   37,   33,   33,  124,  142,  142,   10,
       10,   37,   37,  506,  118,   10,   10,   13,   37,  103,
      113,  498,   13,   13,  124,   13,   13,   13,   13,   13,
       34,   34,   34,  145,  145,  103,  113,  103,  113,  115,
       34,   34,  486,  115,  485,   13,   34,   34,   13,   13,

       13,   15,   15,   15,   15,   15,   15,   15,   15,   38,
       38,  109,  121,  146,  146,  109,  121,  119,   38,   38,
      127,  484,   41,   41,  127,   38,  109,   15,   15,   15,
      169,   41,   41,  119,  483,  119,   15,   41,   41,   15,
       16,   16,   16,   16,   16,   16,   16,   16,  169,   42,
       42,  147,  147,  125,   41,  160,  160,  482,   42,   42,
      162,  162,  165,  165,   42,   42,   16,   16,   16,  125,
      170,  125,  178,  179,  481,   16,  211,  211,   16,   17,
       17,   42,  212,  212,  480,   17,   17,  479,  170,  478,
      178,  179,  213,  213,   17,   17,  222,  222,  255,  255,

       17,   17,   18,   18,  256,  256,  246,  250,   18,   18,
      246,  250,  257,  257,  477,  294,  296,   18,   18,  294,
      296,  299,  299,   18,   18,   21,   21,  300,  300,  301,
      301,   21,   21,  325,  325,  327,  327,  346,  346,  476,
       21,   21,  347,  347,  361,  361,   21,   21,   22,   22,
      362,  362,  373,  373,   22,   22,  374,  374,  475,  473,
      472,  467,  464,   22,   22,  459,  456,  451,  448,   22,
       22,   23,   23,  443,  440,  435,  432,   23,   23,  427,
      424,  419,  416,  411,  408,  403,   23,   23,  400,  395,
      392,  387,   23,   23,   24,   24,  382,  377,  372,  365,

       24,   24,  359,  358,  351,  344,  343,  342,  332,   24,
       24,  328,  323,  322,  321,   24,   24,   27,   27,  320,
      317,  314,  311,   27,   27,  308,  307,  305,  302,  297,
      295,  293,   27,   27,  292,  291,  290,  287,   27,   27,
       28,   28,  286,  285,  282,  281,   28,   28,  280,  277,
      276,  275,  274,  272,  271,   28,   28,  270,  269,  267,
      264,   28,   28,   31,   31,  263,  262,  253,  252,   31,
       31,  251,  249,  245,  244,  243,  242,  241,   31,   31,
      238,  237,  236,  233,   31,   31,   32,   32,  232,  231,
      230,  228,   32,   32,  227,  226,  225,  224,  223,  221,

      220,   32,   32,  219,  218,  215,  207,   32,   32,   35,
       35,   35,  206,  205,  204,  203,   35,   35,  202,   35,
       35,   35,   35,   35,  201,  200,  199,  198,  197,  196,
      195,  190,  189,  188,  183,  182,  181,  176,  174,  173,
      172,  167,   35,   35,   35,  163,  158,  157,  156,  151,
      149,   35,  141,  140,   35,   36,   36,   36,  139,  138,
      136,  135,   36,   36,  134,   36,   36,   36,   36,   36,
      133,  132,  131,  130,  126,  120,  114,  108,  104,   99,
       93,   84,   79,   78,   77,   74,   66,   60,   36,   36,
       36,   59,   58,   57,   56,   54,   53,   36,   49,    0,

       36,   39,    0,    0,   39,   39,   39,    0,   39,   39,
       39,   39,   39,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   39,   39,   39,   43,    0,    0,    0,    0,    0,
       43,   43,    0,   43,   43,   43,   43,   43,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   43,   43,   43,    0,
        0,    0,    0,    0,    0,   43,    0,    0,   43,   44,
        0,    0,    0,    0,    0,   44,   44,    0,   44,   44,
       44,   44,   44,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   44,   44,   44,    0,    0,    0,    0,    0,    0,
       44,    0,    0,   44,   45,    0,   45,   45,   45,   45,
       45,   45,   45,   45,   45,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   45,   45,   45,    0,    0,    0,    0,
        0,    0,   45,    0,    0,   45,   46,    0,   46,   46,
       46,   46,   46,   46,   46,   46,   46,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   46,   46,   46,    0,    0,

        0,    0,    0,    0,   46,    0,    0,   46,   47,    0,
        0,   47,   47,    0,   47,   47,   47,   47,   47,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   47,   47,   47,
        0,    0,    0,    0,    0,    0,   47,    0,    0,   47,
       48,    0,    0,   48,   48,    0,   48,   48,   48,   48,
       48,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   48,
       48,   48,    0,    0,    0,    0,    0,    0,   48,    0,
        0,   48,   81,   81,    0,   81,   81,   81,   81,   81,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   81,    0,    0,    0,   81,   81,
       81,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   81,  101,  101,    0,  101,  101,  101,  101,
      101,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  101,    0,    0,    0,  101,
      101,  101,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  101,  111,  111,    0,  111,  111,  111,
      111,  111,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  111,    0,    0,    0,

      111,  111,  111,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  111,  117,  117,    0,  117,  117,
      117,  117,  117,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  117,    0,    0,
        0,  117,  117,  117,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  117,  123,  123,    0,  123,
      123,  123,  123,  123,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  123,    0,
        0,    0,  123,  123,  123,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  123,  153,  153,    0,

      153,  153,  153,  153,  153,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  153,  153,  153,  185,  185,    0,  185,
      185,  185,  185,  185,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  185,  185,  185,  192,  192,    0,  192,  192,
      192,  192,  192,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  192,  192,  192,  217,  217,    0,  217,  217,  217,
      217,  217,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      217,  217,  217,  235,  235,    0,  235,  235,  235,  235,
      235,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  235,
      235,  235,  240,  240,    0,  240,  240,  240,  240,  240,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  240,  240,
      240,  261,  261,    0,  261,  261,  261,  261,  261,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  261,  261,  261,

      279,  279,    0,  279,  279,  279,  279,  279,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  279,  279,  279,  284,
      284,    0,  284,  284,  284,  284,  284,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  284,  284,  284,  304,  304,
        0,  304,  304,  304,  304,  304,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  304,  304,  304,  313,  313,    0,
      313,  313,  313,  313,  313,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  313,  313,  313,  316,  316,    0,  316,
      316,  316,  316,  316,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  316,  316,  316,  330,  330,    0,  330,  330,
      330,  330,  330,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  330,  330,  330,  336,  336,    0,  336,  336,  336,
      336,  336,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

      336,  336,  336,  339,  339,    0,  339,  339,  339,  339,
      339,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  339,
      339,  339,  350,  350,    0,  350,  350,  350,  350,  350,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  350,  350,
      350,  354,  354,    0,  354,  354,  354,  354,  354,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  354,  354,  354,
      356,  356,    0,  356,  356,  356,  356,  356,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  356,  356,  356,  364,
      364,    0,  364,  364,  364,  364,  364,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  364,  364,  364,  368,  368,
        0,  368,  368,  368,  368,  368,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  368,  368,  368,  370,  370,    0,
      370,  370,  370,  370,  370,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,  370,  370,  370,  376,  376,    0,  376,
      376,  376,  376,  376,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  376,  376,  376,  379,  379,    0,  379,  379,
      379,  379,  379,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  379,  379,  379,  381,  381,    0,  381,  381,  381,
      381,  381,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      381,  381,  381,  386,  386,    0,  386,  386,  386,  386,

      386,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  386,
      386,  386,  389,  389,    0,  389,  389,  389,  389,  389,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  389,  389,
      389,  391,  391,    0,  391,  391,  391,  391,  391,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  391,  391,  391,
      394,  394,    0,  394,  394,  394,  394,  394,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,  394,  394,  394,  397,
      397,    0,  397,  397,  397,  397,  397,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  397,  397,  397,  399,  399,
        0,  399,  399,  399,  399,  399,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  399,  399,  399,  402,  402,    0,
      402,  402,  402,  402,  402,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  402,  402,  402,  405,  405,    0,  405,

      405,  405,  405,  405,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  405,  405,  405,  407,  407,    0,  407,  407,
      407,  407,  407,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  407,  407,  407,  410,  410,    0,  410,  410,  410,
      410,  410,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      410,  410,  410,  413,  413,    0,  413,  413,  413,  413,
      413,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,  413,
      413,  413,  415,  415,    0,  415,  415,  415,  415,  415,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  415,  415,
      415,  418,  418,    0,  418,  418,  418,  418,  418,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  418,  418,  418,
      421,  421,    0,  421,  421,  421,  421,  421,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  421,  421,  421,  423,

      423,    0,  423,  423,  423,  423,  423,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  423,  423,  423,  426,  426,
        0,  426,  426,  426,  426,  426,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  426,  426,  426,  429,  429,    0,
      429,  429,  429,  429,  429,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  429,  429,  429,  431,  431,    0,  431,
      431,  431,  431,  431,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  431,  431,  431,  434,  434,    0,  434,  434,
      434,  434,  434,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  434,  434,  434,  437,  437,    0,  437,  437,  437,
      437,  437,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      437,  437,  437,  439,  439,    0,  439,  439,  439,  439,
      439,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  439,

      439,  439,  442,  442,    0,  442,  442,  442,  442,  442,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  442,  442,
      442,  445,  445,    0,  445,  445,  445,  445,  445,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  445,  445,  445,
      447,  447,    0,  447,  447,  447,  447,  447,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  447,  447,  447,  450,
      450,    0,  450,  450,  450,  450,  450,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  450,  450,  450,  453,  453,
        0,  453,  453,  453,  453,  453,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  453,  453,  453,  455,  455,    0,
      455,  455,  455,  455,  455,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  455,  455,  455,  458,  458,    0,  458,
      458,  458,  458,  458,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,  458,  458,  458,  461,  461,    0,  461,  461,
      461,  461,  461,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  461,  461,  461,  463,  463,    0,  463,  463,  463,
      463,  463,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      463,  463,  463,  489,  489,  489,  489,  489,  489,  489,
      489,  489,  489,  490,  490,  490,  490,  490,  490,  490,
      490,  490,  490,  491,  491,  491,  491,  491,  491,  491,
      491,  491,  491,  492,  492,  492,  492,  492,  492,  492,

      492,  492,  492,  493,  493,  493,  493,  493,  493,  493,
      493,  493,  493,  494,  494,  494,  494,  494,  494,  494,
      494,  494,  494,  495,    0,    0,  495,  496,    0,    0,
      496,    0,  496,  496,  497,    0,    0,  497,  499,    0,
        0,  499,  500,  500,  500,  500,  500,  500,  500,    0,
      500,  500,  501,    0,    0,    0,  501,  501,  501,  501,
      501,  501,  502,    0,    0,  502,  503,  503,    0,  503,
      503,  503,  503,  503,  503,  503,  504,  504,  504,  504,
        0,    0,  504,    0,  504,  504,  505,  505,  505,  505,
        0,  505,  505,  505,  505,  505,  509,  509,  509,  509,

      509,  509,  509,    0,  509,  509,  511,  511,  511,  511,
        0,    0,  511,    0,  511,  511,  512,  512,  512,  512,
        0,  512,  512,  512,  512,  512,  516,  516,  516,  516,
      516,  516,  516,    0,  516,  516,  518,  518,  518,  518,
        0,    0,  518,    0,  518,  518,  519,  519,  519,  519,
        0,  519,  519,  519,  519,  519,  522,  522,  522,  522,
      522,  522,  522,    0,  522,  522,  524,  524,  524,  524,
        0,    0,  524,    0,  524,  524,  525,  525,  525,  525,
        0,  525,  525,  525,  525,  525,  527,  527,  527,  527,
      527,  527,  527,    0,  527,  527,  529,    0,    0,    0,

      529,  529,  529,  529,  529,  529,  530,  530,  530,  530,
        0,    0,  530,    0,  530,  530,  531,  531,  531,  531,
        0,  531,  531,  531,  531,  531,  533,  533,  533,  533,
      533,  533,  533,    0,  533,  533,  535,  535,  535,  535,
        0,    0,  535,    0,  535,  535,  536,  536,  536,  536,
        0,  536,  536,  536,  536,  536,  538,  538,  538,  538,
      538,  538,  538,    0,  538,  538,  540,  540,  540,  540,
        0,    0,  540,    0,  540,  540,  541,  541,  541,  541,
        0,  541,  541,  541,  541,  541,  542,  542,  542,  542,
      542,  542,  542,    0,  542,  542,  543,  543,  543,  543,

        0,    0,  543,    0,  543,  543,  544,  544,  544,  544,
        0,  544,  544,  544,  544,  544,  545,  545,  545,  545,
      545,  545,  545,    0,  545,  545,  546,  546,  546,  546,
        0,    0,  546,    0,  546,  546,  547,  547,  547,  547,
        0,  547,  547,  547,  547,  547,  548,  548,  548,  548,
      548,  548,  548,    0,  548,  548,  549,  549,  549,  549,
        0,    0,  549,    0,  549,  549,  550,  550,  550,  550,
        0,  550,  550,  550,  550,  550,  551,  551,  551,  551,
      551,  551,  551,    0,  551,  551,  552,  552,  552,  552,
        0,    0,  552,    0,  552,  552,  553,  553,  553,  553,

        0,  553,  553,  553,  553,  553,  554,  554,  554,  554,
      554,  554,  554,    0,  554,  554,  555,  555,  555,  555,
        0,    0,  555,    0,  555,  555,  556,  556,  556,  556,
        0,  556,  556,  556,  556,  556,  557,  557,  557,  557,
      557,  557,  557,    0,  557,  557,  558,  558,  558,  558,
        0,    0,  558,    0,  558,  558,  559,  559,  559,  559,
        0,  559,  559,  559,  559,  559,  560,  560,  560,  560,
      560,  560,  560,    0,  560,  560,  561,  561,  561,  561,
        0,    0,  561,    0,  561,  561,  562,  562,  562,  562,
        0,  562,  562,  562,  562,  562,  563,  563,  563,  563,

      563,  563,  563,    0,  563,  563,  564,  564,  564,  564,
        0,    0,  564,    0,  564,  564,  565,  565,  565,  565,
        0,  565,  565,  565,  565,  565,  566,  566,  566,  566,
      566,  566,  566,    0,  566,  566,  567,  567,  567,  567,
        0,    0,  567,    0,  567,  567,  568,  568,  568,  568,
        0,  568,  568,  568,  568,  568,  569,  569,  569,  569,
      569,  569,  569,    0,  569,  569,  570,  570,  570,  570,
        0,    0,  570,    0,  570,  570,  571,  571,  571,  571,
        0,  571,  571,  571,  571,  571,  572,  572,  572,  572,
      572,  572,  572,    0,  572,  572,  573,  573,  573,  573,

        0,    0,  573,    0,  573,  573,  574,  574,  574,  574,
        0,  574,  574,  574,  574,  574,  575,  575,  575,  575,
      575,  575,  575,    0,  575,  575,  576,  576,  576,  576,
        0,    0,  576,    0,  576,  576,  577,  577,  577,  577,
        0,  577,  577,  577,  577,  577,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488

    } ;

static const flex_int16_t yy_rule_linenum[38] =
    {   0,
      160,  166,  172,  178,  184,  190,  196,  211,  223,  228,
      255,  261,  267,  271,  277,  288,  294,  299,  304,  308,
      312,  321,  327,  333,  339,  347,  353,  359,  365,  370,
      376,  381,  387,  392,  396,  398,  402
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET

/*
 * We want a reentrant scanner.
 */
/*
 * We don't read interactively from the terminal.
 */
/*
 * We want to stop processing when we get to the end of the input.
 */
/*
 * The type for the state we keep for the scanner (and parser).
 */
/*
 * Prefix scanner routines with "ascend_" rather than "yy", so this scanner
 * can coexist with other scanners.
 */
/*
 * We have to override the memory allocators so that we don't get
 * "unused argument" warnings from the yyscanner argument (which
 * we don't use, as we have a global memory allocator).
 *
 * We provide, as macros, our own versions of the routines generated by Flex,
 * which just call malloc()/realloc()/free() (as the Flex versions do),
 * discarding the extra argument.
 */
/* ascend_scanner.l
 *
 * Wiretap Library
 * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

#include <stdlib.h>
#include <string.h>

#include "wtap-int.h"
#include "ascendtext.h"
#include "ascend-int.h"
#include "ascend_parser.h"
#include "file_wrappers.h"

/*
 * Disable diagnostics in the code generated by Flex.
 */
DIAG_OFF_FLEX()

static int ascend_yyinput(void *buf, ascend_state_t *parser_state) {
    int c = file_getc(parser_state->fh);
    if (c == EOF) {
        parser_state->err = file_error(parser_state->fh,
            &parser_state->err_info);
        if (parser_state->err == 0)
        parser_state->err = WTAP_ERR_SHORT_READ;
        return YY_NULL;
    } else {
        *(char *) buf = c;
        return 1;
    }
}

#define YY_INPUT(buf, result, max_size) \
  do { (result) = ascend_yyinput((buf), yyextra); } while (0)

/* Count bytes read. This is required in order to rewind the file
 * to the beginning of the next packet, since flex reads more bytes
 * before executing the action that does yyterminate(). */
#define YY_USER_ACTION do { yyextra->token.length = yyleng; } while (0);

#define NO_USER "<none>"

#ifndef HAVE_UNISTD_H
#define YY_NO_UNISTD_H
#endif

/*
 * Sleazy hack to suppress compiler warnings in yy_fatal_error().
 */
#define YY_EXIT_FAILURE ((void)yyscanner, 2)

/*
 * Macros for the allocators, to discard the extra argument.
 */
#define ascend_alloc(size, yyscanner)		(void *)malloc(size)
#define ascend_realloc(ptr, size, yyscanner)	(void *)realloc((char *)(ptr), (size))
#define ascend_free(ptr, yyscanner)		free((char *)ptr)

#define INITIAL 0
#define sc_gen_task 1
#define sc_gen_time_s 2
#define sc_gen_time_u 3
#define sc_gen_octets 4
#define sc_gen_counter 5
#define sc_gen_byte 6
#define sc_wds_user 7
#define sc_wds_sess 8
#define sc_wdd_date_d 9
#define sc_wdd_date_m 10
#define sc_wdd_date_y 11
#define sc_wdd_time 12
#define sc_wdd_time_h 13
#define sc_wdd_time_m 14
#define sc_wdd_time_s 15
#define sc_wdd_cause 16
#define sc_wdd_callnum 17
#define sc_wdd_chunk 18
#define sc_wdd_chunknum 19
#define sc_wdd_type 20
#define sc_chardisp 21
#define sc_isdn_call 22
#define sc_ether_direction 23

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
/* %if-c-only */
#include <unistd.h>
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

#define YY_EXTRA_TYPE ascend_state_t *

/* %if-c-only Reentrant structure and macros (non-C++). */
/* %if-reentrant */

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

/* %if-c-only */

static int yy_init_globals ( yyscan_t yyscanner );

/* %endif */

/* %if-reentrant */

int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* %endif */

/* %endif End reentrant structures and macros. */

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

/* %if-bison-bridge */
/* %endif */

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

/* %not-for-header */
#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  , yyscan_t yyscanner);
    
#endif
/* %ok-for-header */

/* %endif */

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif
/* %ok-for-header */

/* %endif */
#endif

/* %if-c-only */

/* %endif */

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* %if-c-only Standard (non-C++) definition */
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
/* %% [5.0] fread()/read() definition of YY_INPUT goes here unless we're doing C++ \ */\
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\
/* %if-c++-only C++ definition \ */\
/* %endif */

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
/* %if-c-only */
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

/* %if-tables-serialization structures and prototypes */
/* %not-for-header */
/* %ok-for-header */

/* %not-for-header */
/* %tables-yydmap generated elements */
/* %endif */
/* end tables serialization structures and prototypes */

/* %ok-for-header */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
/* %if-c-only Standard (non-C++) definition */

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

/* %% [6.0] YY_RULE_SETUP definition goes here */
#define YY_RULE_SETUP \
	YY_USER_ACTION

/* %not-for-header */
/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
/* %if-c-only */
			yyin = stdin;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! yyout )
/* %if-c-only */
			yyout = stdout;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
/* %% [7.0] user's declarations go here */

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
/* %% [8.0] yymore()-related code goes here */
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

/* %% [9.0] code to set up and find next match goes here */
		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 489 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 488 );
		yy_cp = yyg->yy_last_accepting_cpos;
		yy_current_state = yyg->yy_last_accepting_state;

yy_find_action:
/* %% [10.0] code to find the action number goes here */
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

/* %% [11.0] code for yylineno update goes here */

do_action:	/* This label is used only to access EOF actions. */

/* %% [12.0] debug code goes here */
		if ( yy_flex_debug )
			{
			if ( yy_act == 0 )
				fprintf( stderr, "--scanner backing up\n" );
			else if ( yy_act < 38 )
				fprintf( stderr, "--accepting rule at line %ld (\"%s\")\n",
				         (long)yy_rule_linenum[yy_act], yytext );
			else if ( yy_act == 38 )
				fprintf( stderr, "--accepting default rule (\"%s\")\n",
				         yytext );
			else if ( yy_act == 39 )
				fprintf( stderr, "--(end of buffer or a NUL)\n" );
			else
				fprintf( stderr, "--EOF (start condition %d)\n", YY_START );
			}

		switch ( yy_act )
	{ /* beginning of action switch */
/* %% [13.0] actions go here */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
{
    BEGIN(sc_ether_direction);
    yyextra->token.u16_val = ASCEND_PFX_ETHER;
    return ETHER_PREFIX;
}
	YY_BREAK
case 2:
YY_RULE_SETUP
{
    BEGIN(sc_isdn_call);
    yyextra->token.u16_val = ASCEND_PFX_ISDN_X;
    return ISDN_PREFIX;
}
	YY_BREAK
case 3:
YY_RULE_SETUP
{
    BEGIN(sc_isdn_call);
    yyextra->token.u16_val = ASCEND_PFX_ISDN_R;
    return ISDN_PREFIX;
}
	YY_BREAK
case 4:
YY_RULE_SETUP
{
    BEGIN(sc_wds_user);
    yyextra->token.u16_val = ASCEND_PFX_WDS_X;
    return WDS_PREFIX;
}
	YY_BREAK
case 5:
YY_RULE_SETUP
{
    BEGIN(sc_wds_user);
    yyextra->token.u16_val = ASCEND_PFX_WDS_R;
    return WDS_PREFIX;
}
	YY_BREAK
case 6:
YY_RULE_SETUP
{
    BEGIN(sc_wds_user);
    yyextra->token.u16_val = ASCEND_PFX_WDS_X;
    return WDS_PREFIX;
}
	YY_BREAK
case 7:
YY_RULE_SETUP
{
    BEGIN(sc_wds_user);
    yyextra->token.u16_val = ASCEND_PFX_WDS_R;
    return WDS_PREFIX;
}
	YY_BREAK
/*
  * If we allow an arbitrary non-zero number of non-left-parentheses after
  * "ETHER", that means that some file that has ETHER followed by a lot of
  * text (see, for example, tpncp/tpncp.dat in the source tree) can cause
  * either an infinite loop or a loop that take forever to finish, as the
  * scanner keeps swallowing characters.  Limit it to 20 characters.
  *
  * XXX - any reason to require at least two of them?
  */
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
{
    BEGIN(sc_gen_task);
    return STRING;
}
	YY_BREAK
/*
  * If we allow an arbitrary non-zero number of non-slash, non-left-parentheses,
  * non-colon characters after "PRI-XMIT", that means that some file that has
  * PRI-XMIT= followed by a lot of text can cause either an infinite loop or
  * a loop that take forever to finish, as the scanner keeps swallowing
  * characters.  Limit it to 20 characters.
  */
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
{
    BEGIN(sc_gen_task);
    return DECNUM;
}
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
{
    char *atcopy = g_strdup(yytext);
    char colon = input(yyscanner);
    char after = input(yyscanner);
    int retval = STRING;

    unput(after); unput(colon);

    if (after != '(' && after != ' ') {
        BEGIN(sc_wds_sess);
        if (yyextra->pseudo_header != NULL && yyextra->pseudo_header->user[0] == '\0') {
        (void) g_strlcpy(yyextra->pseudo_header->user, atcopy, ASCEND_MAX_STR_LEN);
        }
    } else {	/* We have a version 7 file */
        BEGIN(sc_gen_task);
        if (yyextra->pseudo_header != NULL && yyextra->pseudo_header->user[0] == '\0') {
        (void) g_strlcpy(yyextra->pseudo_header->user, NO_USER, ASCEND_MAX_STR_LEN);
        }
        /* Are valid values ever > 2^32? If so we need to adjust YYSTYPE and a lot of */
        /* upstream code accordingly. */
        yyextra->token.u32_val = (guint32) strtoul(yytext, NULL, 10);
        retval = DECNUM;
    }
    g_free (atcopy);
    return retval;
}
	YY_BREAK
case 11:
YY_RULE_SETUP
{
    BEGIN(sc_gen_task);
    yyextra->token.u32_val = (guint32) strtoul(yytext, NULL, 10);
    return DECNUM;
}
	YY_BREAK
case 12:
YY_RULE_SETUP
{
    BEGIN(sc_gen_time_s);
    yyextra->token.u32_val = (guint32) strtoul(yytext, NULL, 16);
    return HEXNUM;
}
	YY_BREAK
case 13:
YY_RULE_SETUP
{
    return STRING;
}
	YY_BREAK
case 14:
YY_RULE_SETUP
{
    BEGIN(sc_gen_time_u);
    yyextra->token.u32_val = (guint32) strtoul(yytext, NULL, 10);
    return DECNUM;
}
	YY_BREAK
case 15:
YY_RULE_SETUP
{
    char *atcopy = g_strdup(yytext);
    BEGIN(sc_gen_octets);
    /* only want the most significant 2 digits. convert to usecs */
    if (strlen(atcopy) > 2)
        atcopy[2] = '\0';
    yyextra->token.u32_val = (guint32) strtoul(atcopy, NULL, 10) * 10000;
    g_free(atcopy);
    return DECNUM;
}
	YY_BREAK
case 16:
YY_RULE_SETUP
{
    BEGIN(sc_gen_counter);
    yyextra->token.u32_val = (guint32) strtoul(yytext, NULL, 10);
    return DECNUM;
}
	YY_BREAK
case 17:
YY_RULE_SETUP
{
    BEGIN(sc_gen_byte);
    return COUNTER;
}
	YY_BREAK
case 18:
YY_RULE_SETUP
{
    yyextra->token.u8_val = (guint8) strtoul(yytext, NULL, 16);
    return HEXBYTE;
}
	YY_BREAK
case 19:
YY_RULE_SETUP
{
    BEGIN(sc_chardisp);
}
	YY_BREAK
case 20:
YY_RULE_SETUP
{
    BEGIN(sc_gen_byte);
}
	YY_BREAK
case 21:
YY_RULE_SETUP
{
    BEGIN(sc_wdd_date_m);
    return WDD_DATE;
}
	YY_BREAK
/*
  * Scan m/d/y as three separate m, /d/, and y tokens.
  * We could alternately treat m/d/y as a single token.
  */
case 22:
YY_RULE_SETUP
{
    BEGIN(sc_wdd_date_d);
    yyextra->token.u32_val = (guint32) strtoul(yytext, NULL, 10);
    return WDD_DECNUM;
}
	YY_BREAK
case 23:
YY_RULE_SETUP
{
    BEGIN(sc_wdd_date_y);
    yyextra->token.u32_val = (guint32) strtoul(yytext+1, NULL, 10);
    return WDD_DECNUM;
}
	YY_BREAK
case 24:
YY_RULE_SETUP
{
    BEGIN(sc_wdd_time);
    yyextra->token.u32_val = (guint32) strtoul(yytext, NULL, 10);
    return WDD_DECNUM;
}
	YY_BREAK
case 25:
YY_RULE_SETUP
{
    BEGIN(sc_wdd_time_h);
    return WDD_TIME;
}
	YY_BREAK
/*
  * Scan h:m:s as three separate h, :m:, and s tokens similar to above.
  */
case 26:
YY_RULE_SETUP
{
    BEGIN(sc_wdd_time_m);
    yyextra->token.u32_val = (guint32) strtoul(yytext, NULL, 10);
    return WDD_DECNUM;
}
	YY_BREAK
case 27:
YY_RULE_SETUP
{
    BEGIN(sc_wdd_time_s);
    yyextra->token.u32_val = (guint32) strtoul(yytext+1, NULL, 10);
    return WDD_DECNUM;
}
	YY_BREAK
case 28:
YY_RULE_SETUP
{
    BEGIN(sc_wdd_cause);
    yyextra->token.u32_val = (guint32) strtoul(yytext, NULL, 10);
    return WDD_DECNUM;
}
	YY_BREAK
case 29:
YY_RULE_SETUP
{
    BEGIN(sc_wdd_callnum);
    return WDD_CAUSE;
}
	YY_BREAK
case 30:
YY_RULE_SETUP
{
    BEGIN(sc_wdd_chunk);
    (void) g_strlcpy(yyextra->token.str_val, yytext, ASCEND_MAX_STR_LEN);
    return WDD_CALLNUM;
}
	YY_BREAK
case 31:
YY_RULE_SETUP
{
    BEGIN(sc_wdd_chunknum);
    return WDD_CHUNK;
}
	YY_BREAK
case 32:
YY_RULE_SETUP
{
    BEGIN(sc_wdd_type);
    yyextra->token.u32_val = (guint32) strtoul(yytext, NULL, 16);
    return HEXNUM;
}
	YY_BREAK
case 33:
YY_RULE_SETUP
{
    BEGIN(sc_gen_task);
    return KEYWORD;
}
	YY_BREAK
case 34:
YY_RULE_SETUP
{
    return SLASH_SUFFIX;
}
	YY_BREAK
case 35:
YY_RULE_SETUP
{ return HEXNUM; }
	YY_BREAK
case 36:
YY_RULE_SETUP
{ return KEYWORD; }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(sc_gen_task):
case YY_STATE_EOF(sc_gen_time_s):
case YY_STATE_EOF(sc_gen_time_u):
case YY_STATE_EOF(sc_gen_octets):
case YY_STATE_EOF(sc_gen_counter):
case YY_STATE_EOF(sc_gen_byte):
case YY_STATE_EOF(sc_wds_user):
case YY_STATE_EOF(sc_wds_sess):
case YY_STATE_EOF(sc_wdd_date_d):
case YY_STATE_EOF(sc_wdd_date_m):
case YY_STATE_EOF(sc_wdd_date_y):
case YY_STATE_EOF(sc_wdd_time):
case YY_STATE_EOF(sc_wdd_time_h):
case YY_STATE_EOF(sc_wdd_time_m):
case YY_STATE_EOF(sc_wdd_time_s):
case YY_STATE_EOF(sc_wdd_cause):
case YY_STATE_EOF(sc_wdd_callnum):
case YY_STATE_EOF(sc_wdd_chunk):
case YY_STATE_EOF(sc_wdd_chunknum):
case YY_STATE_EOF(sc_wdd_type):
case YY_STATE_EOF(sc_chardisp):
case YY_STATE_EOF(sc_isdn_call):
case YY_STATE_EOF(sc_ether_direction):
{ yyterminate(); }
	YY_BREAK
case 37:
/* rule 37 can match eol */
YY_RULE_SETUP
;
	YY_BREAK
case 38:
YY_RULE_SETUP
ECHO;
	YY_BREAK

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
/* %if-c-only */
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
/* %endif */
/* %if-c++-only */
/* %endif */
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
/* %% [14.0] code to do back-up for compressed tables and set up yy_cp goes here */
				yy_cp = yyg->yy_last_accepting_cpos;
				yy_current_state = yyg->yy_last_accepting_state;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */
/* %ok-for-header */

/* %if-c++-only */
/* %not-for-header */
/* %ok-for-header */

/* %endif */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
/* %if-c-only */
static int yy_get_next_buffer (yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

/* %if-c-only */
/* %not-for-header */
    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

/* %% [15.0] code to get the start state into yy_current_state goes here */
	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
/* %% [16.0] code to find the next state goes here */
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 489 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
/* %if-c-only */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
/* %% [17.0] code to find the next state, and perhaps do backing up, goes here */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 489 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 488);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT
/* %if-c-only */

    static void yyunput (int c, char * yy_bp , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = yyg->yy_n_chars + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

/* %% [18.0] update yylineno here */

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}
/* %if-c-only */

/* %endif */
#endif

/* %if-c-only */
#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

/* %endif */
/* %if-c++-only */
/* %endif */
{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

/* %% [19.0] update BOL and yylineno */

	return c;
}
/* %if-c-only */
#endif	/* ifndef YY_NO_INPUT */
/* %endif */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
/* %if-c-only */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/* %if-c++-only */
/* %endif */

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
/* %if-c-only */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/* %if-c-only */
static void yy_load_buffer_state  (yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
/* %if-c-only */
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
/* %endif */
/* %if-c++-only */
/* %endif */
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
/* %if-c-only */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/* %if-c++-only */
/* %endif */

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
/* %if-c-only */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
/* %if-c-only */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

/* %if-c-only */
	b->yy_input_file = file;
/* %endif */
/* %if-c++-only */
/* %endif */
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

/* %if-c-only */

        b->yy_is_interactive = 0;
    
/* %endif */
/* %if-c++-only */
/* %endif */
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
/* %if-c-only */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/* %if-c-or-c++ */
/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
/* %if-c-only */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}
/* %endif */

/* %if-c-or-c++ */
/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
/* %if-c-only */
void yypop_buffer_state (yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}
/* %endif */

/* %if-c-or-c++ */
/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
/* %if-c-only */
static void yyensure_buffer_stack (yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}
/* %endif */

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

/* %if-c-only */
static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}
/* %endif */
/* %if-c++-only */
/* %endif */

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/* %if-c-only */
/* %if-reentrant */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/* %endif */

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/* %if-reentrant */

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/* %endif */

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* %endif */

/* %if-reentrant */
/* Accessor methods for yylval and yylloc */

/* %if-bison-bridge */
/* %endif */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

/* %endif if-c-only */

/* %if-c-only */
static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}
/* %endif */

/* %if-c-only SNIP! this currently causes conflicts with the c++ scanner */
/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

/* %if-reentrant */
    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
/* %endif */
    return 0;
}
/* %endif */

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

/* %if-tables-serialization definitions */
/* %define-yytables   The name for this specific scanner's tables. */
#define YYTABLES_NAME "yytables"
/* %endif */

/* %ok-for-header */

/*
 * Turn diagnostics back on, so we check the code that we've written.
 */
DIAG_ON_FLEX()

